summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/replication_coordinator_test_fixture.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/repl/replication_coordinator_test_fixture.h')
-rw-r--r--src/mongo/db/repl/replication_coordinator_test_fixture.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/src/mongo/db/repl/replication_coordinator_test_fixture.h b/src/mongo/db/repl/replication_coordinator_test_fixture.h
index 5ffab24a8ef..972e2f503ae 100644
--- a/src/mongo/db/repl/replication_coordinator_test_fixture.h
+++ b/src/mongo/db/repl/replication_coordinator_test_fixture.h
@@ -59,18 +59,17 @@ class TopologyCoordinatorImpl;
class ReplCoordTest : public mongo::unittest::Test {
public:
/**
* Makes a ResponseStatus with the given "doc" response and optional elapsed time "millis".
*/
- static ResponseStatus makeResponseStatus(const BSONObj& doc,
- Milliseconds millis = Milliseconds(0));
+ static executor::RemoteCommandResponse makeResponseStatus(
+ const BSONObj& doc, Milliseconds millis = Milliseconds(0));
/**
* Makes a ResponseStatus with the given "doc" response, metadata and optional elapsed time
* "millis".
*/
- static ResponseStatus makeResponseStatus(const BSONObj& doc,
- const BSONObj& metadata,
- Milliseconds millis = Milliseconds(0));
+ static executor::RemoteCommandResponse makeResponseStatus(
+ const BSONObj& doc, const BSONObj& metadata, Milliseconds millis = Milliseconds(0));
/**
* Constructs a ReplSetConfig from the given BSON, or raises a test failure exception.
@@ -59,18 +59,17 @@ class TopologyCoordinatorImpl;
public:
/**
- * Makes a ResponseStatus with the given "doc" response and optional elapsed time "millis".
+ * Makes a command response with the given "doc" response and optional elapsed time "millis".
*/
@@ -59,18 +59,17 @@ class TopologyCoordinatorImpl;
/**
- * Makes a ResponseStatus with the given "doc" response, metadata and optional elapsed time
+ * Makes a command response with the given "doc" response, metadata and optional elapsed time
* "millis".
*/